/*
 * Copyright (C) 2005 - 2006
 * Anastasios Skarlatidis
 *
 * This program developed as part of the dissertation entitled:
 * A Framework for Implementation and Visualization of Evolutionary Algorithms,
 * by Anastasios Skarlatidis.
 * Technological Educational Institute of Thessaloniki,
 * Department of Information Technology
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

package examples.functions;

import gr.teithe.it.ga.IChromosome;
import gr.teithe.it.ga.eval.AbstractMinimizationEvaluator;
import gr.teithe.it.ga.representation.DoubleRepresentation;
import gr.teithe.it.ga.representation.genes.DoubleGene;
import gr.teithe.it.util.annotations.Require;

/**
 * @author <a href="mailto:anskarl@yahoo.com">Anastasios Skarlatidis</a>
 */
@Require(value = DoubleRepresentation.class)
public final class AckleyFunction extends AbstractMinimizationEvaluator {

    private final double c1 = 20.0;
    private final double c2 = 0.2;
    private final double c3 = 2 * Math.PI;

    @SuppressWarnings({"unchecked"})
    public void evaluate(IChromosome c) {
        IChromosome<DoubleGene> rc = (IChromosome<DoubleGene>) c;
        final int length = rc.length();
        double part1 = 0.0;
        double part2 = 0.0;

        for (int i = 0; i < length; i++) {
            double value = rc.getGene(i).getValue();
            part1 += value * value;
            part2 += Math.cos(c3 * value);
        }
        c.setFitnessValue(-c1 * Math.exp(-c2 * Math.sqrt(part1 / length)) - Math.exp(part2 / length) + c1 + Math.E);
    }
}
