/*
 * Copyright (C) 2005 - 2006
 * Anastasios Skarlatidis
 *
 * This program developed as part of the dissertation entitled:
 * A Framework for Implementation and Visualization of Evolutionary Algorithms,
 * by Anastasios Skarlatidis.
 * Technological Educational Institute of Thessaloniki,
 * Department of Information Technology
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

package examples.functions;

import gr.teithe.it.ga.IChromosome;
import gr.teithe.it.ga.eval.AbstractMinimizationEvaluator;
import gr.teithe.it.ga.representation.BinaryRepresentation;
import gr.teithe.it.ga.representation.genes.BinaryGene;
import gr.teithe.it.ga.representation.genes.IGene;
import gr.teithe.it.util.BinaryUtils;

import gr.teithe.it.util.annotations.Require;

/**
 * @author <a href="mailto:anskarl@yahoo.com">Anastasios Skarlatidis</a>
 */
@Require(value = BinaryRepresentation.class)
public final class RastriginFunctionBinary extends AbstractMinimizationEvaluator {

    public void evaluate(IChromosome c) {
        IGene[] genes = c.getGenes();

        double fitness = 0.0;
        double curr = 0.0;

        for (int i = 0; i < genes.length; i++) {
            curr = BinaryUtils.parseDouble((BinaryGene) genes[i]);
            fitness += (Math.pow(curr, 2) - 10.0 * Math.cos(2.0 * Math.PI * curr)) + 10.0;
        }

        c.setFitnessValue(fitness);
    }

}
