/*
 * Copyright (C) 2005 - 2006
 * Anastasios Skarlatidis
 *
 * This program developed as part of the dissertation entitled:
 * A Framework for Implementation and Visualization of Evolutionary Algorithms,
 * by Anastasios Skarlatidis.
 * Technological Educational Institute of Thessaloniki,
 * Department of Information Technology
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

package examples.wasps;

import javolution.util.FastList;

import java.io.*;

/**
 * @author <a href="mailto:anskarl@yahoo.com">Anastasios Skarlatidis</a>
 */
final class WaspNestsLoader {

    private final FileReader frd;
    private final StreamTokenizer st;

    public WaspNestsLoader(File file) throws FileNotFoundException {
        frd = new FileReader(file);
        st = new StreamTokenizer(new BufferedReader(frd));
        st.commentChar('#');
    }

    public FastList<WaspsNest> load() throws IOException {
        st.parseNumbers();
        FastList<WaspsNest> list = FastList.newInstance();
        int numberOfWasps=0;
        int x,y;
        st.nextToken();
        while(st.ttype != StreamTokenizer.TT_EOF){
            numberOfWasps = (int)st.nval;
            st.nextToken();
            x = (int)st.nval;
            st.nextToken();
            y = (int)st.nval;
            list.addLast(WaspsNest.create(numberOfWasps,x,y));
            st.nextToken();
        }
        /*for(WaspsNest nest: list){
            System.out.println(nest.numberOfWasps+" "+nest.x+" "+nest.y);
        }//*/
        return list;
    }


}
